InspectNotificationsSession class

Implemented types

Constructors

InspectNotificationsSession(List<Map<String, dynamic>> _notifications, IOSink _outputStream, Future<String> _executeCommand(String))

Properties

hashCode → int
The hash code for this object.
no setterinherited
isActive → bool
Check if the session is still active
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

exit() → void
Exit the session and clean up resources
override
getPrompt() → String
Get the current prompt to display to the user
override
handleInput(String input) → bool
Handle input from the user during the interactive session Returns true if input was handled, false if session should exit
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited