InteractiveSession class abstract

Base interface for interactive sessions in the REPL

Implementers

Constructors

InteractiveSession()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isActive → bool
Check if the session is still active
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

exit() → void
Exit the session and clean up resources
getPrompt() → String
Get the current prompt to display to the user
handleInput(String input) → bool
Handle input from the user during the interactive session Returns true if input was handled, false if session should exit
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited