REPL class

Constructors

REPL({Stream<String>? inputStream, IOSink? outputStream})

Properties

atClient ↔ AtClient
getter/setter pair
currentMode ↔ ReplMode
getter/setter pair
currentSession ↔ InteractiveSession?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inputStream ↔ Stream<String>
getter/setter pair
outputStream ↔ IOSink
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

authenticate({required AtRootDomain rootDomain, required String atSign, String? keysPath}) → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited